@@ -9,7 +9,7 @@ use base qw{ Astro::App::Satpass2::ParseTime };
 
 use Astro::App::Satpass2::Utils qw{ CODE_REF HASH_REF };
 
-our $VERSION = '0.031_01';
+our $VERSION = '0.031_02';
 
 use constant DUMMY	=> 'DUMMY';
 
@@ -77,7 +77,8 @@ sub use_perltime {
 
 sub _attr {
     my ( $self ) = @_;
-    return $self->{ __PACKAGE__() } ||= {};
+    my $pkg = __PACKAGE__;
+    return $self->{$pkg} ||= {};
 }
 
 sub _call_code {
